@@ -42,6 +42,8 @@
 #include "callbacks.h"
 #include "baobab-prefs.h"
 
+#include "gedit-spinner.h"
+
 static GnomeVFSMonitorHandle *handle_mtab;
 static GnomeVFSMonitorHandle *handle_home;
 
@@ -58,12 +60,7 @@ static GQueue *iterstack = NULL;
 #define BUSY_IMAGE_PATH		BAOBAB_PIX_DIR "busy.gif"
 #define DONE_IMAGE_PATH		BAOBAB_PIX_DIR "done.png"
 
-static GdkPixbufAnimation *busy_image = NULL;
-static GdkPixbuf *done_image = NULL;
 
-static gboolean filter_adv_search (struct BaobabSearchRet *);
-static void initialize_search_variables (void);
-	      			  
 static gboolean
 scan_is_local (const gchar *uri_dir)
 {
@@ -86,34 +83,14 @@ scan_is_local (const gchar *uri_dir)
 void
 set_busy (gboolean busy)
 {
-	GtkWidget *image;
-	GError *err = NULL;
-
-	image = glade_xml_get_widget (baobab.main_xml, "busyimage");
-
-	if (busy) {
-		if (busy_image == NULL) {
-			busy_image = gdk_pixbuf_animation_new_from_file (BUSY_IMAGE_PATH, &err);
-			if (err != NULL) {
-				g_warning ("Could not load \"busy\" animation (%s)\n",  err->message);
-				g_error_free (err);
-				return;
-			}
-		}
-
-		gtk_image_set_from_animation (GTK_IMAGE (image), busy_image);
+	if (busy == TRUE) {
+		gedit_spinner_start (GEDIT_SPINNER (baobab.spinner));
+ 		baobab_ringschart_freeze_updates (baobab.ringschart);
+		baobab_ringschart_set_init_depth (baobab.ringschart, 0);
 	}
 	else {
-		if (done_image == NULL) {
-			done_image = gdk_pixbuf_new_from_file (DONE_IMAGE_PATH, &err);
-			if (err != NULL) {
-				g_warning ("Could not load \"done\" image (%s)\n",  err->message);
-				g_error_free (err);
-				return;
-			}
-		}
-
-		gtk_image_set_from_pixbuf (GTK_IMAGE (image), done_image);
+		gedit_spinner_stop (GEDIT_SPINNER (baobab.spinner));
+ 		baobab_ringschart_thaw_updates (baobab.ringschart);
 	}
 }
 
@@ -126,11 +103,12 @@ start_proc_on_dir (const gchar *dir)
 	GdkCursor *cursor = NULL;
 	GtkWidget *ck_allocated;
 
-	switch_view (VIEW_TREE);
-
 	if (!baobab_check_dir (dir))
 		return;
-
+		
+	if (iterstack !=NULL)
+		return;
+		
 	g_string_assign (baobab.last_scan_command, dir);
 	baobab.STOP_SCANNING = FALSE;
 	set_busy (TRUE);
@@ -179,212 +157,16 @@ start_proc_on_dir (const gchar *dir)
 	gtk_tree_view_columns_autosize (GTK_TREE_VIEW (baobab.tree_view));
 	baobab.STOP_SCANNING = TRUE;
 	g_queue_free (iterstack);
+	iterstack = NULL;
 	baobab.CONTENTS_CHANGED_DELAYED = FALSE;
 }
 
 void
-start_search (const gchar *searchname, const gchar *dir)
+rescan_current_dir (void)
 {
-	GdkCursor *cursor = NULL;
+	g_return_if_fail (baobab.last_scan_command != NULL);
 
-	switch_view (VIEW_SEARCH);
-	initialize_search_variables ();
-	baobab.STOP_SCANNING = FALSE;
-	set_busy (TRUE);
-	check_menu_sens (TRUE);
-
-	/* change the cursor */
-	if (baobab.window->window) {
-		cursor = gdk_cursor_new (GDK_WATCH);
-		gdk_window_set_cursor (baobab.window->window, cursor);
-	}
-
-	gtk_list_store_clear (baobab.model_search);
-
-	if (dir == NULL)
-		searchDir ("file:///", searchname);
-	else
-		searchDir (dir, searchname);
-
-	/* cursor clean up */
-	if (baobab.window->window) {
-		gdk_window_set_cursor (baobab.window->window, NULL);
-		if (cursor)
-			gdk_cursor_unref (cursor);
-	}
-
-	set_busy (FALSE);
-	check_menu_sens (FALSE);
-	set_statusbar (_("Ready"));
-
-	set_label_search (baobab.number_found_files,
-			  baobab.size_found_files);
-	if (get_NB_page () == VIEW_SEARCH)
-		show_label (VIEW_SEARCH);
-	gtk_tree_view_columns_autosize (GTK_TREE_VIEW (baobab.tree_search));
-	baobab.STOP_SCANNING = TRUE;
-	bbSearchOpt.dont_recurse_dir = FALSE;
-}
-
-static gchar *
-get_last_mod (time_t timeacc)
-{
-	gchar snum[21];
-	struct tm *lt;
-	size_t len;
-
-	lt = localtime (&timeacc);
-	len = strftime (snum, sizeof (snum), "%Y-%m-%d %R:%S", lt);
-
-	return g_strndup (snum, len);
-}
-
-static gchar *
-get_owner (uid_t own_id)
-{
-	struct passwd *pw;
-
-	pw = getpwuid (own_id);
-
-	return g_strdup (pw != NULL ? pw->pw_name : _("Unknown"));
-}
-
-static void
-prepare_firstcol (GString *text, struct BaobabSearchRet *bbret)
-{
-	gchar *basename, *path, *last_mod, *owner, *size, *alloc_size;
-
-	check_UTF (text);
-	basename = g_path_get_basename (text->str);
-	path = strdup (text->str);
-
-	last_mod = get_last_mod (bbret->lastacc);
-	owner = get_owner (bbret->owner);
-
-	size = gnome_vfs_format_file_size_for_display (bbret->size);
-	alloc_size = gnome_vfs_format_file_size_for_display (bbret->alloc_size);
-
-	g_string_printf (text,
-			 "<big><b>%s</b></big>\n"
-			 "<small>%s %s</small>\n"
-		         "<small>%s %s    %s %s</small>\n"
-			 "<small>%s (%s %s) - %s</small>",
-			 basename,
-			 _("Full path:"), path,
-			 _("Last Modification:"), last_mod,
-			 _("Owner:"), owner,
-			 size, _("Allocated bytes:"), alloc_size,
-			 gnome_vfs_mime_get_description (bbret->mime_type));
-
-	g_free (basename);
-	g_free (path);
-	g_free (last_mod);
-	g_free (owner);
-	g_free (size);
-	g_free (alloc_size);
-}
-
-/*
- * fill the search model
- */
-void
-fill_search_model (struct BaobabSearchRet *bbret)
-{
-	GtkTreeIter iter;
-	GString *testo1;
-	GdkPixbuf *picon;
-	char *gicon;
-
-	if (!filter_adv_search (bbret))
-		return;
-
-	gicon =
-	    gnome_icon_lookup_sync (gtk_icon_theme_get_default (), NULL,
-				    bbret->fullpath, NULL,
-				    GNOME_ICON_LOOKUP_FLAGS_NONE, NULL);
-	picon =
-	    gtk_icon_theme_load_icon (gtk_icon_theme_get_default (), gicon,
-				      36, GTK_ICON_LOOKUP_USE_BUILTIN,
-				      NULL);
-
-	testo1 = g_string_new (bbret->fullpath);
-	prepare_firstcol (testo1, bbret);
-
-	gtk_list_store_append (baobab.model_search, &iter);
-	gtk_list_store_set (baobab.model_search, &iter,
-			    COL0_ICON, picon, COL1_STRING, testo1->str,
-			    /* COL2_STRING,testo2->str, */
-			    COL_FULLPATH, bbret->fullpath,
-			    COL_FILETYPE, bbret->mime_type,
-			    COL_SIZE, bbret->size,
-			    COL_LASTACCESS, bbret->lastacc,
-			    COL_OWNER, bbret->owner, -1);
-
-	baobab.number_found_files++;
-	baobab.size_found_files += bbret->size;
-	g_object_unref (picon);
-	g_string_free (testo1, TRUE);
-}
-
-void
-initialize_search_variables (void)
-{
-	baobab.number_found_files = 0;
-	baobab.size_found_files = 0;
-}
-
-static gboolean
-filter_adv_search (struct BaobabSearchRet *bbret)
-{
-	gboolean flag = TRUE;
-	GDate *filedate, *today;
-	gint days;
-	gint maxinterval = 100;
-
-	if ((bbSearchOpt.mod_date == NONE) &&
-	     bbSearchOpt.size_limit == NONE) {
-		return TRUE;
-	}
-
-	switch (bbSearchOpt.mod_date) {
-
-	case LAST_WEEK:
-	case LAST_MONTH:
-		filedate = g_date_new ();
-		today = g_date_new ();
-		g_date_set_time (filedate, (GTime) bbret->lastacc);
-		g_date_set_time (today, time (NULL));
-		days = g_date_days_between (filedate, today);
-		if (bbSearchOpt.mod_date == LAST_WEEK) {
-			maxinterval = 7;
-		}
-		if (bbSearchOpt.mod_date == LAST_MONTH) {
-			maxinterval = 30;
-		}
-		if (days > maxinterval) {
-			flag = FALSE;
-		}
-
-		g_date_free (today);
-		g_date_free (filedate);
-		break;
-	}
-
-	switch (bbSearchOpt.size_limit) {
-
-	case SIZE_SMALL:
-		if (bbret->size >= (guint64) 102400)
-			flag = FALSE;
-		break;
-
-	case SIZE_MEDIUM:
-		if (bbret->size >= (guint64) 1048576)
-			flag = FALSE;
-
-		break;
-	}
-
-	return flag;
+	start_proc_on_dir (baobab.last_scan_command->str);
 }
 
 /*
@@ -396,7 +178,7 @@ prefill_model (struct chan_data *data)
 	GString *cdir;
 	char *basename;
 	GtkTreeIter iter, iterparent;
-	GtkTreePath *path;
+	gchar *str;
 
 	cdir = g_string_new ("");
 
@@ -405,6 +187,8 @@ prefill_model (struct chan_data *data)
 		firstiter = iter;
 	}
 	else if (data->depth == 1) {
+		GtkTreePath *path;
+
 		gtk_tree_store_append (baobab.model, &iter, &firstiter);
 		path = gtk_tree_model_get_path (GTK_TREE_MODEL (baobab.model),
 						&firstiter);
@@ -443,16 +227,23 @@ prefill_model (struct chan_data *data)
 	/* check UTF-8 and locale */
 	check_UTF (cdir);
 
-	g_string_append (cdir, " &lt;== ");
-	g_string_append (cdir, _("scanning..."));
-	gtk_tree_store_set (baobab.model, &iter, COL_DIR_NAME, cdir->str,
-			    COL_H_FULLPATH, "", COL_H_ELEMENTS, -1, -1);
+	str = g_strdup_printf ("<small><i>%s</i></small>", _("Scanning..."));
+
+	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (baobab.tree_view), TRUE);
+	gtk_tree_store_set (baobab.model, &iter,
+			    COL_DIR_NAME, cdir->str,
+			    COL_H_FULLPATH, "",
+			    COL_H_ELEMENTS, -1, 
+ 			    COL_H_PERC, -1.0,
+			    COL_DIR_SIZE, str,
+			    COL_ELEMENTS, str, -1);
+
+	g_string_free (cdir, TRUE);
+	g_free(str);
 
 	while (gtk_events_pending ()) {
 		gtk_main_iteration ();
 	}
-
-	g_string_free (cdir, TRUE);
 }
 
 /*
@@ -462,41 +253,30 @@ void
 first_row (void)
 {
 	char *size;
-	gfloat perc;
-	gchar textperc[10];
-	GdkPixbuf *bar;
+	gdouble perc;
+	char *label;
 
+	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (baobab.tree_view), FALSE);
 	gtk_tree_store_append (baobab.model, &firstiter, NULL);
 	size = gnome_vfs_format_file_size_for_display (g_fs.used);
 	g_assert(g_fs.total != 0);
-	perc = ((gfloat) g_fs.used * 100) / (gfloat) g_fs.total;
-	g_sprintf (textperc, " %.1f %%", perc);
-	bar = set_bar ((g_fs.used * 100) / g_fs.total);
+	perc = ((gdouble) g_fs.used * 100) / (gdouble) g_fs.total;
 
+	label = g_strdup_printf ("<i>%s</i>", _("Total filesystem usage:"));
 	gtk_tree_store_set (baobab.model, &firstiter,
-			    COL_DIR_NAME,
-			    _("<i>Total filesystem usage:</i>"),
+			    COL_DIR_NAME, label,
 			    COL_H_FULLPATH, "",
-			    COL_BAR, bar,
 			    COL_H_PERC, perc,
-			    COL_DIR_SIZE, size, COL_PERC, textperc,
+			    COL_DIR_SIZE, size,
 			    COL_H_SIZE, g_fs.used,
 			    COL_H_ALLOCSIZE, g_fs.used,
 			    COL_H_ELEMENTS, -1, -1);
 
-	g_object_unref (bar);
 	g_free (size);
+	g_free (label);
 }
 
-/* fills model during scanning
- *  model:
- *
- *	0, $dir,					   1, $fullpath,
- *	2, set_bar($perc),				   3, $perc,
- *	4, calc($size),	        			   5, $size,
- *	6, sprintf("% 4s",$elements)." "._('elements'),	   7, $elements,
- *	8, text showing hardlink size,			   9, $HLsize
- */
+/* fills model during scanning */
 void
 fill_model (struct chan_data *data)
 {
@@ -519,8 +299,6 @@ fill_model (struct chan_data *data)
 	g_free (basename_cstr);
 
 	check_UTF (basename);
-	g_string_prepend (basename, "<b>");
-	g_string_append (basename, "</b>");
 
 	iter = pop_iter_from_stack ();
 
@@ -537,21 +315,24 @@ fill_model (struct chan_data *data)
 
 	elementi = g_string_new ("");
 	g_string_printf (elementi,
-			 ngettext ("% 5d object", "% 5d objects",
+			 ngettext ("% 5d item", "% 5d items",
 				   data->elements), data->elements);
 
 	size = gnome_vfs_format_file_size_for_display (data->size);
 	alloc_size = gnome_vfs_format_file_size_for_display (data->alloc_size);
 
 	gtk_tree_store_set (baobab.model, &iter,
-			    COL_DIR_NAME, basename->str, COL_H_FULLPATH,
-			    data->dir, COL_H_PERC, 0.0, COL_DIR_SIZE,
+			    COL_DIR_NAME, basename->str,
+			    COL_H_FULLPATH, data->dir,
+			    COL_H_PERC, -1.0, 
+			    COL_DIR_SIZE,
 			    baobab.show_allocated ? alloc_size : size,
-			    COL_H_SIZE, data->size, COL_ELEMENTS,
-			    elementi->str, COL_H_ELEMENTS, data->elements,
-			    COL_HARDLINK, hardlinks->str, COL_H_HARDLINK,
-			    data->tempHLsize, COL_H_ALLOCSIZE,
-			    data->alloc_size, -1);
+			    COL_H_SIZE, data->size,
+			    COL_ELEMENTS, elementi->str,
+			    COL_H_ELEMENTS, data->elements,
+			    COL_HARDLINK, hardlinks->str,
+			    COL_H_HARDLINK, data->tempHLsize,
+			    COL_H_ALLOCSIZE, data->alloc_size, -1);
 
 	while (gtk_events_pending ()) {
 		gtk_main_iteration ();
@@ -634,7 +415,8 @@ list_find (gconstpointer a, gconstpointer b)
 gboolean
 is_excluded_dir (const gchar *dir)
 {
-		
+	g_return_if_fail (dir != NULL);
+
 	return (baobab.bbExcludedDirs &&
 		(g_slist_find_custom (baobab.bbExcludedDirs, dir, list_find) != NULL));
 }
@@ -642,15 +424,12 @@ is_excluded_dir (const gchar *dir)
 void
 set_toolbar_visible (gboolean visible)
 {
-	GtkWidget *toolbar;
 	GtkWidget *menu;
 
-	toolbar = glade_xml_get_widget (baobab.main_xml, "toolbar1");
-
 	if (visible)
-		gtk_widget_show (toolbar);
+		gtk_widget_show (baobab.toolbar);
 	else
-		gtk_widget_hide (toolbar);
+		gtk_widget_hide (baobab.toolbar);
 
 	/* make sure the check menu item is consistent */
 	menu = glade_xml_get_widget (baobab.main_xml, "view_tb");
@@ -660,57 +439,145 @@ set_toolbar_visible (gboolean visible)
 void
 set_statusbar_visible (gboolean visible)
 {
-	GtkWidget *statusbar;
 	GtkWidget *menu;
 
-	statusbar = glade_xml_get_widget (baobab.main_xml, "statusbar1");
-
 	if (visible)
-		gtk_widget_show (statusbar);
+		gtk_widget_show (baobab.statusbar);
 	else
-		gtk_widget_hide (statusbar);
+		gtk_widget_hide (baobab.statusbar);
 
 	/* make sure the check menu item is consistent */
 	menu = glade_xml_get_widget (baobab.main_xml, "view_sb");
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu), visible);
 }
 
+void
+set_statusbar (const gchar *text)
+{
+	gtk_statusbar_pop (GTK_STATUSBAR (baobab.statusbar), 1);
+	gtk_statusbar_push (GTK_STATUSBAR (baobab.statusbar), 1, text);
+
+	while (gtk_events_pending ())
+		gtk_main_iteration ();
+}
+
+static void
+toolbar_reconfigured_cb (GtkToolItem  *item,
+			 GeditSpinner *spinner)
+{
+	GtkToolbarStyle style;
+	GtkIconSize size;
+
+	style = gtk_tool_item_get_toolbar_style (item);
+
+	if (style == GTK_TOOLBAR_BOTH)
+	{
+		size = GTK_ICON_SIZE_DIALOG;
+	}
+	else
+	{
+		size = GTK_ICON_SIZE_LARGE_TOOLBAR;
+	}
+
+	gedit_spinner_set_size (spinner, size);
+}
+
 static void
 baobab_toolbar_style (GConfClient *client,
 	      	      guint cnxn_id,
 	      	      GConfEntry *entry,
 	      	      gpointer user_data)
 {
-	GtkWidget *toolbar;
 	gchar *toolbar_setting;
 
-	toolbar = glade_xml_get_widget(baobab.main_xml, "toolbar1");
 	toolbar_setting = baobab_gconf_get_string_with_default (baobab.gconf_client,
 								SYSTEM_TOOLBAR_STYLE,
 								"both");
 
 	if (!strcmp(toolbar_setting, "icons")) {
-		gtk_toolbar_set_style(GTK_TOOLBAR(toolbar), GTK_TOOLBAR_ICONS);
+		gtk_toolbar_set_style (GTK_TOOLBAR(baobab.toolbar),
+				       GTK_TOOLBAR_ICONS);
 	}
 	else if (!strcmp(toolbar_setting, "both")) {
-		gtk_toolbar_set_style(GTK_TOOLBAR(toolbar), GTK_TOOLBAR_BOTH);
+		gtk_toolbar_set_style (GTK_TOOLBAR(baobab.toolbar),
+				       GTK_TOOLBAR_BOTH);
 	}
 	else if (!strcmp(toolbar_setting, "both-horiz")) {
-		gtk_toolbar_set_style(GTK_TOOLBAR(toolbar), GTK_TOOLBAR_BOTH_HORIZ);
+		gtk_toolbar_set_style (GTK_TOOLBAR(baobab.toolbar),
+				       GTK_TOOLBAR_BOTH_HORIZ);
 	}
 	else if (!strcmp(toolbar_setting, "text")) {
-		gtk_toolbar_set_style(GTK_TOOLBAR(toolbar), GTK_TOOLBAR_TEXT);
+		gtk_toolbar_set_style (GTK_TOOLBAR(baobab.toolbar),
+				       GTK_TOOLBAR_TEXT);
 	}
 
 	g_free (toolbar_setting);
 }
 
+static void
+baobab_create_toolbar (void)
+{
+	GtkWidget *toolbar;
+	GtkToolItem *item;
+	GtkToolItem *separator;
+	gboolean visible;
+
+	toolbar = glade_xml_get_widget (baobab.main_xml, "toolbar1");
+	if (toolbar == NULL) {
+		g_printerr ("Could not build toolbar\n");
+		return;
+	}
+
+	baobab.toolbar = toolbar;
+
+	separator = gtk_separator_tool_item_new ();
+	gtk_separator_tool_item_set_draw (GTK_SEPARATOR_TOOL_ITEM (separator), FALSE);
+	gtk_tool_item_set_expand (GTK_TOOL_ITEM (separator), TRUE);	
+	gtk_container_add (GTK_CONTAINER (toolbar), GTK_WIDGET (separator));
+	gtk_widget_show (GTK_WIDGET (separator));
+
+	baobab.spinner = gedit_spinner_new ();
+	item = gtk_tool_item_new ();		
+	gtk_container_add (GTK_CONTAINER (item), baobab.spinner);
+  	gtk_container_add (GTK_CONTAINER (toolbar), GTK_WIDGET (item));
+	gtk_widget_show (GTK_WIDGET (baobab.spinner));
+	gtk_widget_show (GTK_WIDGET (item));
+
+	g_signal_connect (item, "toolbar-reconfigured",
+			  G_CALLBACK (toolbar_reconfigured_cb), baobab.spinner);
+
+	baobab_toolbar_style (NULL, 0, NULL, NULL);
+
+	visible = gconf_client_get_bool (baobab.gconf_client,
+					 BAOBAB_TOOLBAR_VISIBLE_KEY,
+					 NULL);
+
+	set_toolbar_visible (visible);
+}
+
+static void
+baobab_create_statusbar (void)
+{
+	gboolean visible;
+
+	baobab.statusbar = glade_xml_get_widget (baobab.main_xml,
+						 "statusbar1");
+	if (baobab.statusbar == NULL) {
+		g_printerr ("Could not build statusbar\n");
+		return;
+	}
+
+	visible = gconf_client_get_bool (baobab.gconf_client,
+					 BAOBAB_STATUSBAR_VISIBLE_KEY,
+					 NULL);
+	set_statusbar_visible (visible);
+}
+
 static void
 baobab_init (void)
 {
 	GnomeVFSResult result;
 	GnomeVFSVolumeMonitor *volmonitor;
-	gboolean visible;
 
 	/* Load Glade */
 	baobab.main_xml = glade_xml_new (BAOBAB_GLADE_FILE,
@@ -719,7 +586,6 @@ baobab_init (void)
 
 	/* Misc */
 	baobab.label_scan = NULL;
-	baobab.label_search = NULL;
 	baobab.last_scan_command = g_string_new ("/");
 	baobab.CONTENTS_CHANGED_DELAYED = FALSE;
 	baobab.STOP_SCANNING = TRUE;
@@ -737,7 +603,7 @@ baobab_init (void)
 	baobab.bbExcludedDirs = gconf_client_get_list (baobab.gconf_client, PROPS_SCAN_KEY,
 						       GCONF_VALUE_STRING, NULL);
 	
-	/*	Verify if gconf wrongly contains root dir exclusion, and remove it from gconf. */
+	/* Verify if gconf wrongly contains root dir exclusion, and remove it from gconf. */
 	if (is_excluded_dir("/")) {
 		baobab.bbExcludedDirs = g_slist_delete_link (baobab.bbExcludedDirs, 
 						g_slist_find_custom(baobab.bbExcludedDirs, 
@@ -751,27 +617,9 @@ baobab_init (void)
 							    PROPS_ENABLE_HOME_MONITOR,
 							    NULL);
 
-	/* toolbar & statusbar visibility */
-	visible = gconf_client_get_bool (baobab.gconf_client,
-					 BAOBAB_TOOLBAR_VISIBLE_KEY,
-					 NULL);
-	set_toolbar_visible (visible);
-	visible = gconf_client_get_bool (baobab.gconf_client,
-					 BAOBAB_STATUSBAR_VISIBLE_KEY,
-					 NULL);
-	set_statusbar_visible (visible);
+	baobab_create_toolbar ();
 
-	/* set the toolbar style */
-	baobab_toolbar_style(NULL, 0, NULL, NULL);
-	
-	/* initialize bbSearchOpt variables */
-	bbSearchOpt.filename = g_string_new ("");
-	bbSearchOpt.dir = g_string_new (g_get_home_dir ());
-	bbSearchOpt.mod_date = NONE;
-	bbSearchOpt.size_limit = NONE;
-	bbSearchOpt.exact = TRUE;
-	bbSearchOpt.search_whole = FALSE;
-	bbSearchOpt.dont_recurse_dir = FALSE;
+	baobab_create_statusbar ();
 
 	/* start VFS monitoring */
 	handle_home = NULL;
@@ -788,9 +636,9 @@ baobab_init (void)
 					contents_changed_cb, NULL);
 
 	if (result != GNOME_VFS_OK) {
-		message (_("Cannot initialize GNOME VFS monitoring\n"
-			   "Some real-time auto-detect function will not be available!"),
-			 NULL);
+		message (_("Could not initialize GNOME VFS monitoring"),
+			 _("Changes to your home folder will not be monitored."),
+			 GTK_MESSAGE_WARNING, NULL);
 		g_print ("homedir:%s\n",
 			 gnome_vfs_result_to_string (result));
 	}
@@ -800,10 +648,7 @@ static void
 baobab_shutdown (void)
 {
 	g_free (baobab.label_scan);
-	g_free (baobab.label_search);
 	g_string_free (baobab.last_scan_command, TRUE);
-	g_string_free (bbSearchOpt.filename, TRUE);
-	g_string_free (bbSearchOpt.dir, TRUE);
 
 	if (handle_mtab)
 		gnome_vfs_monitor_cancel (handle_mtab);
@@ -817,11 +662,43 @@ baobab_shutdown (void)
 
 	if (baobab.gconf_client)
 		g_object_unref (baobab.gconf_client);
+}
 
-	if (done_image)
-		g_object_unref (done_image);
-	if (busy_image)
-		g_object_unref (busy_image);
+static void
+initialize_ringschart (void)
+{
+        GtkWidget *hpaned_main;
+        GtkWidget *ringschart_frame;
+
+        baobab.ringschart = GTK_WIDGET (baobab_ringschart_new ());
+        baobab_ringschart_set_model_with_columns (baobab.ringschart,
+                                                  GTK_TREE_MODEL (baobab.model),
+                                                  COL_DIR_NAME,
+                                                  COL_DIR_SIZE,
+                                                  COL_H_FULLPATH,
+                                                  COL_H_PERC,
+                                                  COL_H_ELEMENTS,
+                                                  NULL);
+        baobab_ringschart_set_init_depth (baobab.ringschart, 1);
+
+        g_signal_connect (baobab.ringschart, "sector_activated",
+                          G_CALLBACK (on_rchart_sector_activated), NULL);
+
+        ringschart_frame = gtk_frame_new (NULL);
+        gtk_frame_set_label_align (GTK_FRAME (ringschart_frame), 0.0, 0.0);
+        gtk_frame_set_shadow_type (GTK_FRAME (ringschart_frame), GTK_SHADOW_IN);
+
+        gtk_container_add (GTK_CONTAINER (ringschart_frame),
+                           baobab.ringschart);
+
+        hpaned_main = glade_xml_get_widget (baobab.main_xml, "hpaned_main");
+        gtk_paned_pack2 (GTK_PANED (hpaned_main),
+                         ringschart_frame, TRUE, TRUE);
+        gtk_paned_set_position (GTK_PANED (hpaned_main), 480);
+
+        baobab_ringschart_draw_center (baobab.ringschart, TRUE);
+
+        gtk_widget_show_all (ringschart_frame);
 }
 
 int
@@ -853,25 +730,21 @@ main (int argc, char *argv[])
 	if (g_fs.total == 0) {
 		g_print("No mount points detected! Aborting...\n");
 		goto closing;
-		}
-	
+	}
+
 	set_label_scan (&g_fs);
+	show_label ();
 
 	baobab.window = glade_xml_get_widget (baobab.main_xml, "baobab_window");
 	gtk_window_set_position (GTK_WINDOW (baobab.window),
 				 GTK_WIN_POS_CENTER);
 
 	baobab.tree_view = create_directory_treeview ();
-	baobab.tree_search = create_filesearch_treeview ();
-	set_label_search (0, 0);
 
-	switch_view (VIEW_SEARCH);
-	switch_view (VIEW_TREE);
-	show_label (VIEW_TREE);
-	set_busy (FALSE);
+	set_glade_widget_sens("menurescan",FALSE);
 
 	/* set allocated space checkbox */
-	gtk_toggle_button_set_active ((GtkToggleButton *)
+	gtk_check_menu_item_set_active ((GtkCheckMenuItem *)
 				      glade_xml_get_widget (baobab.
 							    main_xml,
 							    "ck_allocated"),
@@ -883,6 +756,9 @@ main (int argc, char *argv[])
 	first_row ();
 	set_statusbar (_("Ready"));
 
+	/* The ringschart */
+	initialize_ringschart ();
+
 	/* commandline */
 	if (argc > 1) {
 		gchar *uri_shell;
