@@ -40,6 +40,12 @@
 #include "baobab-prefs.h"
 #include "baobab-remote-connect-dialog.h"
 
+void
+on_menuscanhome_activate (GtkMenuItem *menuitem, gpointer user_data)
+{
+	start_proc_on_dir (g_get_home_dir ());
+}
+
 void
 on_menuallfs_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
@@ -66,6 +72,7 @@ on_about_activate (GtkMenuItem *menuitem, gpointer user_data)
 		"Fabio Marzocca <thesaltydog@gmail.com>",
 		"Paolo Borelli <pborelli@katamail.com>",
 		"Benoît Dejean <benoit@placenet.org>",
+		"Igalia (rings-chart widget) <www.igalia.com>",
 		NULL
 	};
 
@@ -73,18 +80,42 @@ on_about_activate (GtkMenuItem *menuitem, gpointer user_data)
 
 	gtk_show_about_dialog (NULL,
 			       "name", _("Baobab"),
-			       "comments", _("A graphical tool to analyse "
+			       "comments", _("A graphical tool to analyze "
 					     "disk usage."),
 			       "version", VERSION,
 			       "copyright", copyright,
 			       "logo-icon-name", "baobab",
 			       "license", "GPL",
-			       "authors", authors, "website",
-			       "http://www.gnome.org/projects/baobab",
+			       "authors", authors, 
 			       "translator-credits",
 			       _("translator-credits"), NULL);
 }
 
+void
+on_menu_expand_activate (GtkMenuItem *menuitem, gpointer user_data)
+{
+	gtk_tree_view_expand_all (GTK_TREE_VIEW (baobab.tree_view));
+}
+
+void
+on_menu_collapse_activate (GtkMenuItem *menuitem, gpointer user_data)
+{
+	gtk_tree_view_collapse_all (GTK_TREE_VIEW (baobab.tree_view));
+}
+
+void
+on_menu_stop_activate (GtkMenuItem *menuitem, gpointer user_data)
+{
+	baobab.STOP_SCANNING = TRUE;
+	stop_scan ();
+}
+
+void
+on_menu_rescan_activate (GtkMenuItem *menuitem, gpointer user_data)
+{
+	rescan_current_dir ();
+}
+
 void
 on_tbscandir_clicked (GtkToolButton *toolbutton, gpointer user_data)
 {
@@ -92,56 +123,9 @@ on_tbscandir_clicked (GtkToolButton *toolbutton, gpointer user_data)
 }
 
 void
-on_sort_alfa_activate (GtkMenuItem *menuitem, gpointer user_data)
+on_tbscanhome_clicked (GtkToolButton *toolbutton, gpointer user_data)
 {
-	if (get_NB_page () == VIEW_TREE) {
-		gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *)
-						      baobab.model,
-						      COL_DIR_NAME,
-						      GTK_SORT_ASCENDING);
-	}
-	if (get_NB_page () == VIEW_SEARCH) {
-		gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *)
-						      baobab.model_search,
-						      COL_FULLPATH,
-						      GTK_SORT_ASCENDING);
-	}
-}
-
-void
-on_by_sort_size_activate (GtkMenuItem *menuitem, gpointer user_data)
-{
-	if (get_NB_page () == VIEW_TREE) {
-		gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *)
-						      baobab.model,
-						      COL_H_SIZE,
-						      GTK_SORT_DESCENDING);
-	}
-	if (get_NB_page () == VIEW_SEARCH) {
-		gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *)
-						      baobab.model_search,
-						      COL_SIZE,
-						      GTK_SORT_DESCENDING);
-	}
-}
-
-void
-on_tbstop_clicked (GtkToolButton *toolbutton, gpointer user_data)
-{
-	baobab.STOP_SCANNING = TRUE;
-	stop_scan ();
-}
-
-void
-on_tbsortalfa_clicked (GtkToolButton *toolbutton, gpointer user_data)
-{
-	on_sort_alfa_activate (NULL, NULL);
-}
-
-void
-on_tbsortnum_clicked (GtkToolButton *toolbutton, gpointer user_data)
-{
-	on_by_sort_size_activate (NULL, NULL);
+	start_proc_on_dir (g_get_home_dir ());
 }
 
 void
@@ -177,81 +161,16 @@ on_menu_scan_rem_activate (GtkMenuItem *menuitem, gpointer user_data)
 }
 
 void
-on_tb_search_clicked (GtkToolButton *toolbutton, gpointer user_data)
+on_tbstop_clicked (GtkToolButton *toolbutton, gpointer user_data)
 {
-	dialog_search ();
+	baobab.STOP_SCANNING = TRUE;
+	stop_scan ();
 }
 
 void
-on_radio_allfs_clicked (GtkButton *button, gpointer user_data)
+on_tbrescan_clicked (GtkToolButton *toolbutton, gpointer user_data)
 {
-	GladeXML *dlg_xml = glade_get_widget_tree ((GtkWidget *) button);
-	gtk_widget_set_sensitive (glade_xml_get_widget (dlg_xml, "entry2"),
-				  FALSE);
-	gtk_widget_set_sensitive (glade_xml_get_widget
-				  (dlg_xml, "btn_select_search"), FALSE);
-}
-
-void
-on_radio_dir_clicked (GtkButton *button, gpointer user_data)
-{
-	GladeXML *dlg_xml = glade_get_widget_tree ((GtkWidget *) button);
-	gtk_widget_set_sensitive (glade_xml_get_widget (dlg_xml, "entry2"),
-				  TRUE);
-	gtk_widget_set_sensitive (glade_xml_get_widget
-				  (dlg_xml, "btn_select_search"), TRUE);
-}
-
-void
-on_btn_select_search_clicked (GtkButton *button, gpointer user_data)
-{
-	GtkWidget *dlg = gtk_widget_get_toplevel ((GtkWidget *) button);
-	GladeXML *dlg_xml = glade_get_widget_tree ((GtkWidget *) button);
-	GtkWidget *entry_dir = glade_xml_get_widget (dlg_xml, "entry2");
-	gchar *dirname = dir_select (TRUE, dlg);
-	if (dirname) {
-		gchar *string_to_display =
-		    gnome_vfs_format_uri_for_display (dirname);
-		gtk_entry_set_text (GTK_ENTRY (entry_dir),
-				    string_to_display);
-		g_free (dirname);
-		g_free (string_to_display);
-	}
-}
-
-void
-on_search_for_a_file_activate (GtkMenuItem *menuitem, gpointer user_data)
-{
-	dialog_search ();
-}
-
-void
-on_notebook1_switch_page (GtkNotebook *notebook,
-			  GtkNotebookPage *page,
-			  guint page_num, gpointer user_data)
-{
-	if (page_num == VIEW_SEARCH) {
-		set_glade_widget_sens("by_type1",TRUE);
-		set_glade_widget_sens("by_date1",TRUE);
-		set_glade_widget_sens("ck_allocated",FALSE);
-		set_glade_widget_sens("menu_treemap",FALSE);
-	}
-
-	if (page_num == VIEW_TREE) {
-		set_glade_widget_sens("by_type1",FALSE);
-		set_glade_widget_sens("by_date1",FALSE);
-		if (baobab.is_local)
-			set_glade_widget_sens("ck_allocated",TRUE);
-		if (baobab.CONTENTS_CHANGED_DELAYED) {
-			baobab.CONTENTS_CHANGED_DELAYED = FALSE;
-			if (baobab.STOP_SCANNING) {
-				contents_changed ();
-
-			}
-		}
-	}
-
-	show_label (page_num);
+	rescan_current_dir ();
 }
 
 gboolean
@@ -273,7 +192,8 @@ open_file_cb (GtkMenuItem *pmenu, gpointer dummy)
 	vfs_uri = gnome_vfs_uri_new (baobab.selected_path);
 
 	if (!gnome_vfs_uri_exists (vfs_uri)) {
-		message (_("The document does not exist."), baobab.window);
+		message (_("The document does not exist."), "",
+		GTK_MESSAGE_INFO, baobab.window);
 		gnome_vfs_uri_unref (vfs_uri);
 		return;
 	}
@@ -282,33 +202,6 @@ open_file_cb (GtkMenuItem *pmenu, gpointer dummy)
 	open_file_with_application (baobab.selected_path);
 }
 
-void
-trash_file_cb (GtkMenuItem *pmenu, gpointer dummy)
-{
-	g_assert (!dummy);
-	g_assert (baobab.selected_path);
-
-	if (trash_file (baobab.selected_path)) {
-		GtkTreeIter iter;
-		guint64 filesize;
-		GtkTreeSelection *selection;
-
-		selection =
-		    gtk_tree_view_get_selection ((GtkTreeView *) baobab.
-						 tree_search);
-		gtk_tree_selection_get_selected (selection, NULL, &iter);
-		gtk_tree_model_get ((GtkTreeModel *) baobab.model_search,
-				    &iter, COL_SIZE, &filesize, -1);
-		gtk_list_store_remove (GTK_LIST_STORE
-				       (baobab.model_search), &iter);
-		set_label_search (baobab.number_found_files - 1,
-				  baobab.size_found_files - filesize);
-		show_label (VIEW_SEARCH);
-		if (baobab.bbEnableHomeMonitor)
-			baobab.CONTENTS_CHANGED_DELAYED = TRUE;
-	}
-}
-
 void
 graph_map_cb (GtkMenuItem *pmenu, gchar *path_to_string)
 {
@@ -345,18 +238,6 @@ trash_dir_cb (GtkMenuItem *pmenu, gpointer dummy)
 	}
 }
 
-void
-list_all_cb (GtkMenuItem *pmenu, gpointer dummy)
-{
-	g_assert (!dummy);
-	g_assert (baobab.selected_path);
-
-	bbSearchOpt.mod_date = NONE;
-	bbSearchOpt.size_limit = NONE;
-	bbSearchOpt.dont_recurse_dir = TRUE;
-	start_search ("*", baobab.selected_path);
-}
-
 void
 volume_changed (GnomeVFSVolumeMonitor *volume_monitor,
 		GnomeVFSVolume *volume)
@@ -364,8 +245,7 @@ volume_changed (GnomeVFSVolumeMonitor *volume_monitor,
 	/* filesystem has changed (mounted or unmounted device) */
 	baobab_get_filesystem (&g_fs);
 	set_label_scan (&g_fs);
-	if (get_NB_page () == VIEW_TREE)
-		show_label (VIEW_TREE);
+	show_label ();
 }
 
 void
@@ -404,35 +284,15 @@ on_pref_menu (GtkMenuItem *menuitem, gpointer user_data)
 }
 
 void
-on_by_type1_activate (GtkMenuItem *menuitem, gpointer user_data)
-{
-	if (get_NB_page () == VIEW_SEARCH) {
-		gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (baobab.model_search),
-						      COL_FILETYPE,
-						      GTK_SORT_ASCENDING);
-	}
-}
-
-void
-on_by_date1_activate (GtkMenuItem *menuitem, gpointer user_data)
-{
-	if (get_NB_page () == VIEW_SEARCH) {
-		gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (baobab.model_search),
-						      COL_LASTACCESS,
-						      GTK_SORT_DESCENDING);
-	}
-}
-
-void
-on_ck_allocated_toggled (GtkToggleButton *togglebutton,
-			 gpointer user_data)
+on_ck_allocated_activate (GtkCheckMenuItem *checkmenuitem,
+			  gpointer user_data)
 {
 	GdkCursor *cursor = NULL;
 
 	if (!baobab.is_local)
 		return;
 
-	baobab.show_allocated = gtk_toggle_button_get_active (togglebutton);
+	baobab.show_allocated = gtk_check_menu_item_get_active (checkmenuitem);
 
 	/* change the cursor */
 	if (baobab.window->window) {
@@ -440,6 +300,9 @@ on_ck_allocated_toggled (GtkToggleButton *togglebutton,
 		gdk_window_set_cursor (baobab.window->window, cursor);
 	}
 
+	baobab_treeview_show_allocated_size (baobab.tree_view,
+					     baobab.show_allocated);
+
 	set_busy (TRUE);
 	set_statusbar (_("Calculating percentage bars..."));
 	gtk_tree_model_foreach (GTK_TREE_MODEL (baobab.model),
@@ -524,10 +387,41 @@ scan_folder_cb (GtkMenuItem *pmenu, gpointer dummy)
 	vfs_uri = gnome_vfs_uri_new (baobab.selected_path);
 
 	if (!gnome_vfs_uri_exists (vfs_uri)) {
-		message (_("The folder does not exist."), baobab.window);
+		message (_("The folder does not exist."), "", GTK_MESSAGE_INFO, baobab.window);
 	}
 
 	gnome_vfs_uri_unref (vfs_uri);
 	
 	start_proc_on_dir (baobab.selected_path);
 }
+
+void
+on_tv_selection_changed (GtkTreeSelection *selection, gpointer user_data)
+{
+	GtkTreeIter iter;
+        
+	if (gtk_tree_selection_get_selected (selection, NULL, &iter)) {
+		GtkTreePath *path;
+                
+		path = gtk_tree_model_get_path (GTK_TREE_MODEL (baobab.model), &iter);
+                
+		baobab_ringschart_set_root (baobab.ringschart, path);
+		
+		gtk_tree_path_free (path);
+	}
+}
+
+void
+on_rchart_sector_activated (BaobabRingschart *rchart, GtkTreeIter *iter)
+{
+	GtkTreePath *path;
+
+	path = gtk_tree_model_get_path (GTK_TREE_MODEL (baobab.model), iter);
+
+	if (!gtk_tree_view_row_expanded (GTK_TREE_VIEW (baobab.tree_view), path))
+                gtk_tree_view_expand_to_path (GTK_TREE_VIEW (baobab.tree_view), path);
+
+	gtk_tree_view_set_cursor (GTK_TREE_VIEW (baobab.tree_view),
+				  path, NULL, FALSE);
+	gtk_tree_path_free (path);
+}
