@@ -13,12 +13,14 @@
 enum {
   TYPE_IMAGE_PNG,
   TYPE_TEXT_URI_LIST,
+  
+  LAST_TYPE
 };
 
 static GtkTargetEntry drag_types[] =
 {
   { "image/png", 0, TYPE_IMAGE_PNG },
-  { "text/uri-list", 0, TYPE_TEXT_URI_LIST }
+  { "text/uri-list", 0, TYPE_TEXT_URI_LIST },
 };
 
 struct ScreenshotDialog
@@ -144,18 +146,18 @@ drag_data_get (GtkWidget          *widget,
 	       GtkSelectionData   *selection_data,
 	       guint               info,
 	       guint               time,
-	       ScreenshotDialog *dialog)
+	       ScreenshotDialog   *dialog)
 {
   if (info == TYPE_TEXT_URI_LIST)
     {
       gchar **uris;
-      
+
       uris = g_new (gchar *, 2);
       uris[0] = g_strconcat ("file://",
                              screenshot_save_get_filename (),
                              NULL);
       uris[1] = NULL;
-
+      
       gtk_selection_data_set_uris (selection_data, uris);
     }
   else if (info == TYPE_IMAGE_PNG)
@@ -310,13 +312,26 @@ screenshot_dialog_get_uri (ScreenshotDialog *dialog)
   gchar *folder;
   const gchar *file_name;
   gchar *uri, *file, *tmp;
+  GError *error;
 
   folder = gtk_file_chooser_get_current_folder_uri (GTK_FILE_CHOOSER (dialog->save_widget));
   file_name = gtk_entry_get_text (GTK_ENTRY (dialog->filename_entry));
 
-  tmp = g_filename_from_utf8 (file_name, -1, NULL, NULL, NULL);
+  error = NULL;
+  tmp = g_filename_from_utf8 (file_name, -1, NULL, NULL, &error);
+  if (error)
+    {
+      g_warning ("Unable to convert `%s' to valid UTF-8: %s\n"
+                 "Falling back to default file.",
+                 file_name,
+                 error->message);
+      g_error_free (error);
+      tmp = g_strdup (_("Screenshot.png"));
+    }
+
   file = gnome_vfs_escape_host_and_path_string (tmp);
   uri = g_build_filename (folder, file, NULL);
+
   g_free (folder);
   g_free (tmp);
   g_free (file);
